@@ -9,7 +9,7 @@ use SWISH::Prog::Config;
 use Scalar::Util qw( blessed );
 use File::Copy ();
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 my $invindex_class = 'SWISH::Prog::Native::InvIndex';
 
@@ -154,7 +154,7 @@ sub start {
 
     $self->debug and carp "opening: $cmd";
 
-    $| = 1;
+    local $| = 1;
 
     open( SWISH, "| $cmd" ) or croak "can't exec $cmd: $!\n";
 
@@ -258,7 +258,7 @@ sub merge {
     }
 
     for (@names) {
-        if ( !-s ) {
+        if ( !-s "$_.prop" ) {  # test .prop file since that is both 2.4 and 2.6
             croak "$_ appears to be empty: $!";
         }
     }
